#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright (c) 2018, 2019 Adam.Dybbroe

# Author(s):

#   Adam.Dybbroe <a000680@c20671.ad.smhi.se>

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Data definitions used in the unit testing."""

import numpy as np

TEST_RAYLEIGH_LUT = np.array([[[[0.08674087,  0.09136106,  0.09747749,  0.10483709,  0.11197918,
                                 0.11989009],
                                [0.08674087,  0.09136106,  0.09747749,  0.10483709,  0.11197918,
                                 0.11989009],
                                [0.08674087,  0.09136106,  0.09747749,  0.10483709,  0.11197918,
                                 0.11989009],
                                [0.08674087,  0.09136106,  0.09747749,  0.10483709,  0.11197918,
                                 0.11989009],
                                [0.08674087,  0.09136106,  0.09747749,  0.10483709,  0.11197918,
                                 0.11989009],
                                [0.08674087,  0.09136106,  0.09747749,  0.10483709,  0.11197918,
                                 0.11989009],
                                [0.08674087,  0.09136106,  0.09747749,  0.10483709,  0.11197918,
                                 0.11989009]],

                               [[0.09136979,  0.10504843,  0.11598711,  0.12744273,  0.13782722,
                                 0.14888419],
                                [0.09136979,  0.10963526,  0.12184923,  0.1340847,  0.1449452,
                                 0.15637435],
                                [0.09136979,  0.11429033,  0.12797441,  0.14119054,  0.15270099,
                                 0.16467966],
                                [0.09136979,  0.11879041,  0.13403104,  0.148341,  0.16060819,
                                 0.17325042],
                                [0.09136979,  0.12289842,  0.13965668,  0.15506919,  0.16811888,
                                 0.18146138],
                                [0.09136979,  0.12638275,  0.14449048,  0.16090511,  0.17467757,
                                 0.18867479],
                                [0.09136979,  0.12903725,  0.14820713,  0.16542192,  0.17977735,
                                 0.19430672]],

                               [[0.09770439,  0.11633682,  0.13083367,  0.14558658,  0.15871949,
                                 0.17253682],
                                [0.09770439,  0.12222815,  0.1385407,  0.15448725,  0.16840136,
                                 0.18287206],
                                [0.09770439,  0.12838849,  0.14689755,  0.16441305,  0.17942691,
                                 0.19487251],
                                [0.09770439,  0.13448341,  0.15538828,  0.1746958,  0.19100924,
                                 0.2076374],
                                [0.09770439,  0.14014703,  0.16343349,  0.18457347,  0.20224202,
                                 0.22012109],
                                [0.09770439,  0.145015,  0.17044669,  0.19326743,  0.21219398,
                                 0.2312444],
                                [0.09770439,  0.14875875,  0.17589334,  0.20006391,  0.2200084,
                                 0.24001162]],

                               [[0.10476043,  0.12730193,  0.14485791,  0.16252086,  0.17811924,
                                 0.19444124],
                                [0.10476043,  0.13393609,  0.1536921,  0.17286742,  0.18949454,
                                 0.20670664],
                                [0.10476043,  0.14103112,  0.16352981,  0.1847426,  0.20284064,
                                 0.22138707],
                                [0.10476043,  0.14816879,  0.17371155,  0.19728105,  0.21712975,
                                 0.23729804],
                                [0.10476043,  0.15488368,  0.18348569,  0.20948288,  0.23116438,
                                 0.25305021],
                                [0.10476043,  0.16070729,  0.19208454,  0.22031873,  0.24370587,
                                 0.26720098],
                                [0.10476043,  0.16521415,  0.19880453,  0.22884041,  0.25360978,
                                 0.27841446]],

                               [[0.1120667,  0.13792118,  0.15820341,  0.17850193,  0.19635648,
                                 0.21498759],
                                [0.1120667,  0.14504395,  0.16782986,  0.18990578,  0.20900121,
                                 0.22872949],
                                [0.1120667,  0.15280494,  0.17878079,  0.20329139,  0.22417869,
                                 0.24555644],
                                [0.1120667,  0.16071741,  0.19027683,  0.21762682,  0.24065644,
                                 0.26404151],
                                [0.1120667,  0.16823316,  0.20142072,  0.23170955,  0.25698766,
                                 0.28249979],
                                [0.1120667,  0.17479622,  0.21129078,  0.24429555,  0.27166918,
                                 0.29917511],
                                [0.1120667,  0.17989942,  0.21903923,  0.25423542,  0.28330877,
                                 0.31243759]],

                               [[0.11937116,  0.1481346,  0.17089175,  0.19360995,  0.21355113,
                                 0.23432958],
                                [0.11937116,  0.15560584,  0.18112014,  0.20584509,  0.22721454,
                                 0.24927552],
                                [0.11937116,  0.1638788,  0.19296584,  0.2204735,  0.24391988,
                                 0.26791269],
                                [0.11937116,  0.17240813,  0.20554543,  0.23631771,  0.26225504,
                                 0.28860074],
                                [0.11937116,  0.18057401,  0.21783453,  0.25199723,  0.28055337,
                                 0.30939347],
                                [0.11937116,  0.18774456,  0.2287764,  0.2660788,  0.29707828,
                                 0.32825708],
                                [0.11937116,  0.19334124,  0.23739642,  0.27723548,  0.31021801,
                                 0.34330076]],

                               [[0.12654956,  0.15792611,  0.18295991,  0.20792282,  0.22981073,
                                 0.25260118],
                                [0.12654956,  0.16566017,  0.19367036,  0.22084379,  0.24432887,
                                 0.26857057],
                                [0.12654956,  0.17434727,  0.20626743,  0.23653543,  0.26235542,
                                 0.2887862],
                                [0.12654956,  0.18339045,  0.21977519,  0.25369033,  0.28231725,
                                 0.31141591],
                                [0.12654956,  0.19210649,  0.2330557,  0.27076817,  0.30235004,
                                 0.33427787],
                                [0.12654956,  0.19979581,  0.24493121,  0.28616577,  0.32050651,
                                 0.35508752],
                                [0.12654956,  0.20581633,  0.25431335,  0.29839623,  0.3349773,
                                 0.3717185]],

                               [[0.13354035,  0.16730131,  0.1944498,  0.22151162,  0.24522819,
                                 0.26991537],
                                [0.13354035,  0.17524174,  0.205561,  0.23501766,  0.26048598,
                                 0.28677997],
                                [0.13354035,  0.18427604,  0.21880829,  0.2516436,  0.2796835,
                                 0.30840391],
                                [0.13354035,  0.19376101,  0.23313227,  0.26996389,  0.301101,
                                 0.33277988],
                                [0.13354035,  0.20295599,  0.24729177,  0.28829286,  0.32269374,
                                 0.35751078],
                                [0.13354035,  0.21110033,  0.25999904,  0.30487204,  0.34232211,
                                 0.38008249],
                                [0.13354035,  0.21749419,  0.27006209,  0.31806877,  0.35799569,
                                 0.39815274]]],


                              [[[0.08281091,  0.08716187,  0.09298168,  0.10001923,  0.10687307,
                                 0.1144878],
                                [0.08281091,  0.08716187,  0.09298168,  0.10001923,  0.10687307,
                                 0.1144878],
                                [0.08281091,  0.08716187,  0.09298168,  0.10001923,  0.10687307,
                                  0.1144878],
                                [0.08281091,  0.08716187,  0.09298168,  0.10001923,  0.10687307,
                                  0.1144878],
                                [0.08281091,  0.08716187,  0.09298168,  0.10001923,  0.10687307,
                                  0.1144878],
                                [0.08281091,  0.08716187,  0.09298168,  0.10001923,  0.10687307,
                                  0.1144878],
                                [0.08281091,  0.08716187,  0.09298168,  0.10001923,  0.10687307,
                                  0.1144878]],

                               [[0.08716995,  0.10021306,  0.11065988,  0.1216338,  0.13160965,
                                 0.14226003],
                                [0.08716995,  0.10463518,  0.11631651,  0.128049,  0.13849056,
                                 0.14950748],
                                [0.08716995,  0.10912296,  0.1222268,  0.134912,  0.14598775,
                                 0.15754336],
                                [0.08716995,  0.11346125,  0.12807082,  0.1418179,  0.15363106,
                                 0.16583586],
                                [0.08716995,  0.11742149,  0.13349886,  0.14831585,  0.16089101,
                                 0.17378008],
                                [0.08716995,  0.12078047,  0.13816285,  0.15395202,  0.16723064,
                                 0.18075909],
                                [0.08716995,  0.12333941,  0.14174888,  0.15831415,  0.17216003,
                                 0.18620792]],

                               [[0.09319749,  0.11099385,  0.1248566,  0.13900164,  0.15162589,
                                 0.16494158],
                                [0.09319749,  0.1166788,  0.13230009,  0.14760584,  0.16099313,
                                 0.17495009],
                                [0.09319749,  0.12262317,  0.14037088,  0.15720059,  0.17165995,
                                 0.18657063],
                                [0.09319749,  0.12850425,  0.14857073,  0.16714016,  0.18286508,
                                 0.19893105],
                                [0.09319749,  0.13396908,  0.1563402,  0.17668797,  0.19373187,
                                 0.21101901],
                                [0.09319749,  0.13866612,  0.16311291,  0.18509151,  0.20335945,
                                 0.22178954],
                                [0.09319749,  0.14227839,  0.16837277,  0.19166087,  0.21091908,
                                 0.23027867]],

                               [[0.09994422,  0.12149718,  0.13830189,  0.15525058,  0.17025477,
                                 0.18599297],
                                [0.09994422,  0.12790467,  0.14684144,  0.16526096,  0.18126944,
                                 0.19788004],
                                [0.09994422,  0.13475703,  0.15635061,  0.17674978,  0.19419189,
                                 0.21210711],
                                [0.09994422,  0.14165039,  0.16619207,  0.18887997,  0.20802703,
                                 0.22752626],
                                [0.09994422,  0.14813536,  0.17563935,  0.20068428,  0.22161558,
                                 0.24279128],
                                [0.09994422,  0.15375949,  0.18395054,  0.21116696,  0.23375829,
                                 0.25650427],
                                [0.09994422,  0.1581119,  0.19044571,  0.21941087,  0.24334718,
                                 0.26737076]],

                               [[0.10695423,  0.13169686,  0.15112838,  0.17062101,  0.18780692,
                                 0.20578228],
                                [0.10695423,  0.13858226,  0.16044164,  0.18166341,  0.20006065,
                                 0.21911074],
                                [0.10695423,  0.14608434,  0.17103583,  0.1946242,  0.21476817,
                                 0.23543075],
                                [0.10695423,  0.15373264,  0.18215705,  0.2085043,  0.23073527,
                                 0.25335845],
                                [0.10695423,  0.16099732,  0.19293745,  0.22213949,  0.2465601,
                                 0.2712599],
                                [0.10695423,  0.16734107,  0.20248544,  0.23432538,  0.26078624,
                                 0.28743204],
                                [0.10695423,  0.1722737,  0.20998096,  0.24394915,  0.27206472,
                                 0.30029422]],

                               [[0.11398264,  0.1415315,  0.16335218,  0.18518472,  0.20439203,
                                 0.22445127],
                                [0.11398264,  0.14875989,  0.17325599,  0.19704159,  0.21764329,
                                 0.23895855],
                                [0.11398264,  0.15676363,  0.18472527,  0.21121712,  0.23384401,
                                 0.25704798],
                                [0.11398264,  0.16501516,  0.19690479,  0.22657043,  0.25162491,
                                 0.27712756],
                                [0.11398264,  0.17291495,  0.20880283,  0.24176386,  0.26936984,
                                 0.2973085],
                                [0.11398264,  0.17985173,  0.2193964,  0.25540876,  0.28539473,
                                 0.31561679],
                                [0.11398264,  0.18526593,  0.22774196,  0.26621935,  0.29813686,
                                 0.33021754]],

                               [[0.12090755,  0.15098237,  0.17500508,  0.19901226,  0.22010869,
                                 0.24212365],
                                [0.12090755,  0.15847121,  0.18538401,  0.21154353,  0.23419963,
                                 0.25763583],
                                [0.12090755,  0.16688254,  0.19759056,  0.2267613,  0.25169498,
                                 0.2772719],
                                [0.12090755,  0.17563844,  0.21067926,  0.24339767,  0.27106816,
                                 0.29925224],
                                [0.12090755,  0.1840774,  0.22354753,  0.2599591,  0.29050988,
                                 0.32145798],
                                [0.12090755,  0.1915222,  0.23505428,  0.2748909,  0.30813053,
                                 0.34167013],
                                [0.12090755,  0.19735117,  0.24414501,  0.2867513,  0.32217416,
                                 0.35782346]],

                               [[0.1276678,  0.1600522,  0.18612415,  0.21216838,  0.23504235,
                                 0.25890392],
                                [0.1276678,  0.16774707,  0.19689983,  0.22527708,  0.24986216,
                                 0.27529743],
                                [0.1276678,  0.17650163,  0.20974655,  0.24141322,  0.26850784,
                                 0.29631659],
                                [0.1276678,  0.18569261,  0.22363701,  0.25919333,  0.2893092,
                                 0.32001024],
                                [0.1276678,  0.19460247,  0.23736778,  0.27698159,  0.31028047,
                                 0.34404862],
                                [0.1276678,  0.20249416,  0.24969012,  0.2930716,  0.3293438,
                                 0.36598808],
                                [0.1276678,  0.2086896,  0.25944826,  0.30587879,  0.34456605,
                                 0.3835521]]]], dtype='float32')

TEST_RAYLEIGH_AZID_COORD = np.array([100.,  110.,  120.,  130.,  140.,  150.,  160.], dtype='float32')
TEST_RAYLEIGH_SATZ_COORD = np.array([1.,  1.25,  1.5,  1.75,  2.,  2.25], dtype='float32')
TEST_RAYLEIGH_SUNZ_COORD = np.array([1.,  1.25,  1.5,  1.75,  2.,  2.25,  2.5,  2.75], dtype='float32')
TEST_RAYLEIGH_WVL_COORD = np.array([440.,  445.], dtype='float32')
